<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

/**
 * Class AMMenu
 */
class AMMenu extends AMController
{
	public function hookDisplayBackOfficeHeader($bootstrap)
	{
		if (!$bootstrap)
			$this->context->controller->addCSS($this->_path.'css/bootstrap.css');

		$this->context->controller->addCSS($this->_path.'css/font-awesome.min.css');
		$this->context->controller->addCSS($this->_path.'css/jquery-ui.min.css');
		$this->context->controller->addCSS($this->_path.'css/jquery.dataTables.min.css');
		$this->context->controller->addCSS($this->_path.'css/jquery.dataTables.bootstrap.css');
		$this->context->controller->addCSS($this->_path.'css/ui.fancytree.min.css');
		$this->context->controller->addCSS($this->_path.'css/bootstrap-colorpicker.min.css');
		$this->context->controller->addCSS($this->_path.'css/fontawesome-iconpicker.min.css');
		$this->context->controller->addCSS($this->_path.'css/menu-layout.css');
		$this->context->controller->addCSS($this->_path.'css/menu-responsive.css');
		$this->context->controller->addCSS($this->_path.'css/menu-editor.css');
		$this->context->controller->addCSS($this->_path.'css/menu-theme.css');
		$this->context->controller->addCSS($this->_path.'css/admin.css');

		$this->context->controller->addJquery();
		$this->context->controller->addJS($this->_path.'js/jquery.awemenu.loader.js');

		return '<script type="text/javascript" src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>';
	}

	public function getThemeCSSfromLess($params)
	{
		$parser = new Less_Parser();
		$parser->parseFile(AM_MODULE_DIR.'less/menu-theme.less');
		$parser->ModifyVars(array(
			'mb-topclr' => '#'.$params['mbtopclr'],
			'mb-btmclr' => '#'.$params['mbbtmclr'],
			'mb-txtclr' => '#'.$params['mbtxtclr'],

			'mb-hvr-topclr' => '#'.$params['mbhvrtopclr'],
			'mb-hvr-btmclr' => '#'.$params['mbhvrbtmclr'],
			'mb-hvr-txtclr' => '#'.$params['mbhvrtxtclr'],

			'mb-bdrclr' => '#'.$params['mbbdrclr'],

			'dd-topclr' => '#'.$params['ddtopclr'],
			'dd-btmclr' => '#'.$params['ddbtmclr'],
			'dd-txtclr' => '#'.$params['ddtxtclr'],
			'dd-ttlclr' => '#'.$params['ddttlclr'],

			'dd-bdrclr' => '#'.$params['ddbdrclr']
		));
		$css = $parser->getCss();

		header("Content-type: text/css; charset: UTF-8");

		return $css;
	}

	public function index()
	{
		$langs = Language::getLanguages();
		$alllangs = array();

		foreach ($langs as $lang)
			$alllangs[] = (object)array(
				'id' => $lang['id_lang'],
				'name' => $lang['name'],
				'iso' => $lang['iso_code']
			);

		$data = array(
			'self' => AM_MODULE_VIEWS_DIR,
			'url' => '../modules/awemenu/awemenu-ajax.php',
            'module_url' => '../modules/awemenu/',
            'langs' => Tools::jsonEncode($alllangs),
			'activelang' => $this->context->language->id,
			'entities' => Tools::jsonEncode(array(
				(object)array('entity' => 'product', 'name' => 'Products', 'format' => 'table'),
				(object)array('entity' => 'category', 'name' => 'Categories', 'format' => 'tree'),
				(object)array('entity' => 'cmspage', 'name' => 'CMS Pages', 'format' => 'table'),
				(object)array('entity' => 'manufacturer', 'name' => 'Manufacturers', 'format' => 'table'),
				(object)array('entity' => 'supplier', 'name' => 'Suppliers', 'format' => 'table')
			))
		);

		return $this->getView('admin/menu/menu', $data, false);
	}

	public function getEditorMenu()
	{
		$this->getModel('Menu');
		$model_menu = new AMMenuModel();

		return Tools::jsonEncode($model_menu->getEditorMenu());
	}

	public function getRevisions()
	{
		$this->getModel('Menu');
		$model_menu = new AMMenuModel();

		return Tools::jsonEncode(array(
			'recordsTotal' => $model_menu->getNumRevisions(),
			'recordsFiltered' => $model_menu->getNumRevisions(),
			'data' => $model_menu->getRevisions()
		));
	}

	public function saveMenu()
	{
		$menu = Tools::jsonDecode(urldecode(Tools::getValue('menu', '{}')));
		$menu->menu = addslashes(Tools::jsonEncode($menu->menu));
		$theme = $menu->theme;
		$menu->theme = addslashes(Tools::jsonEncode($menu->theme));

		// save menu
		$this->getModel('Menu');
		$model_menu = new AMMenuModel();
		$model_menu->saveMenu($menu);

		// save css
		$parser = new Less_Parser();
		$parser->parseFile(AM_MODULE_DIR.'less/menu-theme.less');
		$parser->ModifyVars(array(
			'mb-topclr' => '#'.$theme->{'mb-topclr'},
			'mb-btmclr' => '#'.$theme->{'mb-btmclr'},
			'mb-txtclr' => '#'.$theme->{'mb-txtclr'},

			'mb-hvr-topclr' => '#'.$theme->{'mb-hvr-topclr'},
			'mb-hvr-btmclr' => '#'.$theme->{'mb-hvr-btmclr'},
			'mb-hvr-txtclr' => '#'.$theme->{'mb-hvr-txtclr'},

			'mb-bdrclr' => '#'.$theme->{'mb-bdrclr'},

			'dd-topclr' => '#'.$theme->{'dd-topclr'},
			'dd-btmclr' => '#'.$theme->{'dd-btmclr'},
			'dd-txtclr' => '#'.$theme->{'dd-txtclr'},
			'dd-ttlclr' => '#'.$theme->{'dd-ttlclr'},

			'dd-bdrclr' => '#'.$theme->{'dd-bdrclr'}
		));
		$css = $parser->getCss();
		file_put_contents(AM_MODULE_DIR.'css/menu-theme.css', $css);
		$this->clearCache('front/menu/menu');

		return $this->getEditorMenu();
	}

	public function editRevision($params = array())
	{
		$this->getModel('Menu');
		$model_menu = new AMMenuModel();

		$model_menu->editRevision($params['id']);

		return $this->getEditorMenu();
	}

	public function liveRevision($params = array())
	{
		$this->getModel('Menu');
		$model_menu = new AMMenuModel();
		$this->clearCache('front/menu/menu');

		return $model_menu->liveRevision($params['id']);
	}

	public function deleteRevision($params = array())
	{
		$this->getModel('Menu');
		$model_menu = new AMMenuModel();

		return $model_menu->deleteRevision($params['id']);
	}

	public function getEntity($params = array())
	{
		switch ($params['entity'])
		{
			case 'product':
				$this->getController('admin/Product');
				$products_controller = new AMProduct();
				return $products_controller->getProducts();
			case 'category':
				$this->getController('admin/Category');
				$products_controller = new AMCategory();
				return $products_controller->getCategories();
			case 'cmspage':
				$this->getController('admin/CMSPage');
				$products_controller = new AMCMSPage();
				return $products_controller->getCMSPages();
			case 'manufacturer':
				$this->getController('admin/Manufacturer');
				$products_controller = new AMManufacturer();
				return $products_controller->getManufacturers();
			case 'supplier':
				$this->getController('admin/Supplier');
				$products_controller = new AMSupplier();
				return $products_controller->getSuppliers();
		}

		return false;
	}
}