<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

/**
 * Class AMMenu
 */
class AMMenu extends AMController
{
	public static $css_styles = array();

	public static $css_styles_counter = 1;

	public function hookHeader()
	{
		$this->context->controller->addCSS($this->_path.'css/font-awesome.min.css');
		$this->context->controller->addCSS($this->_path.'css/menu-layout.css');
		$this->context->controller->addCSS($this->_path.'css/menu-responsive.css');
		$this->context->controller->addCSS($this->_path.'css/menu-theme.css');
		$this->context->controller->addCSS($this->_path.'css/menu-custom.css');

		$this->context->controller->addJquery();
		$this->context->controller->addJS($this->_path.'js/menu.js');

		return '<script type="text/javascript" src="//maps.googleapis.com/maps/api/js?v=3.exp"></script>';
	}

	public function getLiveMenu()
	{
		$data = array();

		if (!$this->isViewCached('front/menu/menu'))
		{
			$this->getModel('Menu');
			$model_menu = new AMMenuModel();
			$menu = $model_menu->getLiveMenu();
			AMMenu::validateMenu($menu['menu']);
			AMMenu::generateMenuCSS($menu['menu']);

			$css = "/* autogenerated styles starts */\n";

			foreach (AMMenu::$css_styles as $class_name => $css_style)
				$css .= "#awemenu #awemenu-forpriority .".$class_name.'{'.$css_style."}\n";

			$css .= $menu['theme']->css;
			$css .= "\n/* autogenerated styles ends */";

			file_put_contents(AM_MODULE_DIR.'css/menu-custom.css', $css);

			$data = array(
				'menu' => $menu['menu'],
				'self' => AM_MODULE_VIEWS_DIR,
				'lang_id' => $this->context->language->id
			);
		}

		return $this->getView('front/menu/menu', $data);
	}

	public static function generateMenuCSS($items = array())
	{
		if (!is_array($items) || count($items) == 0)
			return false;

		foreach ($items as $item)
		{
			$css_properties = array();

			if (isset($item->config->color) && !empty($item->config->color))
				$css_properties['color'] = $item->config->color;

			if (isset($item->config->width) && !empty($item->config->width))
				$css_properties['width'] = $item->config->width;

			if (isset($item->config->height) && !empty($item->config->height))
				$css_properties['height'] = $item->config->height;

			if (isset($item->config->{'background-color'}) && !empty($item->config->{'background-color'}))
				$css_properties['background-color'] = $item->config->{'background-color'};

			if (isset($item->config->{'background-image'}) && !empty($item->config->{'background-image'}))
				$css_properties['background-image'] = $item->config->{'background-image'};

			if (isset($item->config->{'background-repeat'}) && !empty($item->config->{'background-repeat'}))
				$css_properties['background-repeat'] = $item->config->{'background-repeat'};

			if (isset($item->config->{'background-position'}) && !empty($item->config->{'background-position'}))
				$css_properties['background-position'] = $item->config->{'background-position'};

			if (isset($item->config->{'font-size'}) && !empty($item->config->{'font-size'}))
				$css_properties['font-size'] = $item->config->{'font-size'};

			if (isset($item->config->bold) && !empty($item->config->bold))
				$css_properties['font-weight'] = (($item->config->bold) ? 'bold' : '');

			if (isset($item->config->italic) && !empty($item->config->italic))
				$css_properties['font-style'] = (($item->config->italic) ? 'italic' : '');

			if (isset($item->config->underline) && !empty($item->config->underline))
				$css_properties['text-decoration'] = (($item->config->underline) ? 'underline' : '');

			$css_style = '';

			$css_style .= implode(';', array_map(function ($v, $k)
			{
				if ($k == 'background-image')
					return sprintf('%s:url(%s)', $k, $v);
				else
					return sprintf('%s:%s', $k, $v);
			},
				$css_properties,
				array_keys($css_properties)));

			if ($css_style != '')
				if (in_array($css_style, AMMenu::$css_styles))
					$item->config->{'class-autogen'} = array_search($css_style, AMMenu::$css_styles);
				else
				{
					AMMenu::$css_styles['am-autogenclass-'.AMMenu::$css_styles_counter] = $css_style;
					$item->config->{'class-autogen'} = 'am-autogenclass-'.AMMenu::$css_styles_counter;
					AMMenu::$css_styles_counter++;
				}

			// badge styles
			$css_style = '';

			if (isset($item->config->{'badge-color'}) && !empty($item->config->{'badge-color'}))
				$css_style .= 'color:'.$item->config->{'badge-color'}.';';

			if (isset($item->config->{'badge-background-color'}) && !empty($item->config->{'badge-background-color'}))
				$css_style .= 'background-color:'.$item->config->{'badge-background-color'}.';';

			if ($css_style != '')
				if (in_array($css_style, AMMenu::$css_styles))
					$item->config->{'class-badge-autogen'} = array_search($css_style, AMMenu::$css_styles);
				else
				{
					AMMenu::$css_styles['am-autogenclass-'.AMMenu::$css_styles_counter] = $css_style;
					$item->config->{'class-badge-autogen'} = 'am-autogenclass-'.AMMenu::$css_styles_counter;
					AMMenu::$css_styles_counter++;
				}

			// dropdown styles
			$css_style = '';

			if (isset($item->config->dropdown->width) && !empty($item->config->dropdown->width))
				$css_style .= 'width:'.$item->config->dropdown->width.';';

			if (isset($item->config->dropdown->height) && !empty($item->config->dropdown->height))
				$css_style .= 'height:'.$item->config->dropdown->height.';';

			if (isset($item->config->dropdown->{'background-color'}) && !empty($item->config->dropdown->{'background-color'}))
				$css_style .= 'background-color:'.$item->config->dropdown->{'background-color'}.';';

			if (isset($item->config->dropdown->{'background-image'}) && !empty($item->config->dropdown->{'background-image'}))
				$css_style .= 'background-image:url(\''.$item->config->dropdown->{'background-image'}.'\');';

			if (isset($item->config->dropdown->{'background-repeat'}) && !empty($item->config->dropdown->{'background-repeat'}))
				$css_style .= 'background-repeat:'.$item->config->dropdown->{'background-repeat'}.';';

			if (isset($item->config->dropdown->{'background-position'}) && !empty($item->config->dropdown->{'background-position'}))
				$css_style .= 'background-position:'.$item->config->dropdown->{'background-position'}.';';

			if ($css_style != '')
				if (in_array($css_style, AMMenu::$css_styles))
					$item->config->{'class-dropdown-autogen'} = array_search($css_style, AMMenu::$css_styles);
				else
				{
					AMMenu::$css_styles['am-autogenclass-'.AMMenu::$css_styles_counter] = $css_style;
					$item->config->{'class-dropdown-autogen'} = 'am-autogenclass-'.AMMenu::$css_styles_counter;
					AMMenu::$css_styles_counter++;
				}

			$item->items = AMMenu::generateMenuCSS($item->items);
		}

		return $items;
	}

	public static function validateMenu($items = array())
	{
		if (!is_array($items) || count($items) == 0)
			return false;

		$id_lang = Context::getContext()->language->id;
		$id_lang_default = Configuration::get('PS_LANG_DEFAULT');

		foreach ($items as $item)
		{
			if ($item->xtype == 'tab' || $item->xtype == 'link')
			{
				switch ($item->config->entity)
				{
					case 'products':
						$product = new Product($item->config->entity_item_id, false, $id_lang);
						$item->config->url = (object)array();

						if (isset($product->id) && !empty($product->id))
						{
							$item->config->text->{'lang_id_'.$id_lang} = $product->name;
							$item->config->url->{'lang_id_'.$id_lang} = Context::getContext()->link
								->getProductLink($item->config->entity_item_id, null, null, null, $id_lang);
						}
						else
							$item->config->url->{'lang_id_'.$id_lang} = '#';

						break;
					case 'categories':
						$category = new Category($item->config->entity_item_id, $id_lang);
						$item->config->url = (object)array();

						if (isset($category->id) && !empty($category->id))
						{
							$item->config->text->{'lang_id_'.$id_lang} = $category->name;
							$item->config->url->{'lang_id_'.$id_lang} = Context::getContext()->link
								->getCategoryLink($item->config->entity_item_id, null, $id_lang);
						}
						else
							$item->config->url->{'lang_id_'.$id_lang} = '#';

						break;
					case 'cmspages':
						$cmspage = new CMS($item->config->entity_item_id, $id_lang);
						$item->config->url = (object)array();

						if (isset($cmspage->id) && !empty($cmspage->id))
						{
							$item->config->text->{'lang_id_'.$id_lang} = $cmspage->meta_title;
							$item->config->url->{'lang_id_'.$id_lang} = Context::getContext()->link
								->getCMSLink($item->config->entity_item_id, null, null, $id_lang);
						}
						else
							$item->config->url->{'lang_id_'.$id_lang} = '#';

						break;
					case 'manufacturers':
						$manufacturer = new Manufacturer($item->config->entity_item_id, $id_lang);
						$item->config->url = (object)array();

						if (isset($manufacturer->id) && !empty($manufacturer->id))
						{
							$item->config->text = $manufacturer->name;
							$item->config->url = Context::getContext()->link
								->getManufacturerLink($item->config->entity_item_id, null, $id_lang);
						}
						else
							$item->config->url = '#';

						break;
					case 'suppliers':
						$supplier = new Supplier($item->config->entity_item_id, $id_lang);
						$item->config->url = (object)array();

						if (isset($supplier->id) && !empty($supplier->id))
						{
							$item->config->text = $supplier->name;
							$item->config->url = Context::getContext()->link
								->getSupplierLink($item->config->entity_item_id, null, $id_lang);
						}
						else
							$item->config->url = '#';

						break;
					case 'custom':
						if (!isset($item->config->text->{'lang_id_'.$id_lang}) || empty($item->config->text->{'lang_id_'.$id_lang}))
							$item->config->text->{'lang_id_'.$id_lang} = $item->config->text->{'lang_id_'.$id_lang_default};

						if (!isset($item->config->url->{'lang_id_'.$id_lang}) || empty($item->config->url->{'lang_id_'.$id_lang}))
							$item->config->url->{'lang_id_'.$id_lang} = $item->config->url->{'lang_id_'.$id_lang_default};

						break;
				}

				if (!isset($item->config->{'custom-text'}->{'lang_id_'.$id_lang}) || empty($item->config->{'custom-text'}->{'lang_id_'.$id_lang}))
					$item->config->{'custom-text'}->{'lang_id_'.$id_lang} = $item->config->{'custom-text'}->{'lang_id_'.$id_lang_default};

				if (!isset($item->config->{'badge-text'}->{'lang_id_'.$id_lang}) || empty($item->config->{'badge-text'}->{'lang_id_'.$id_lang}))
					$item->config->{'badge-text'}->{'lang_id_'.$id_lang} = $item->config->{'badge-text'}->{'lang_id_'.$id_lang_default};
			}

			if ($item->xtype == 'html' && (!isset($item->config->content->{'lang_id_'.$id_lang}) || empty($item->config->content->{'lang_id_'.$id_lang})))
				$item->config->content->{'lang_id_'.$id_lang} = $item->config->content->{'lang_id_'.$id_lang_default};

			$item->items = AMMenu::validateMenu($item->items);
		}

		return $items;
	}
}