<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

/**
 * Class AMController
 */
class AMController extends Module
{
	private $page_name = '';

	protected static $countActiveCurrencies = array();

	public function __construct()
	{
		$this->name = AWEMENU_NAME;
		$this->displayName = AWEMENU_DISPLAYNAME;
		$this->author = AWEMENU_AUTHOR;
		$this->version = AWEMENU_VERSION;

		$this->tab = 'front_office_features';
		$this->need_instance = 0;

		parent::__construct();
	}

	protected function getController($controller)
	{
		include_once AM_MODULE_CONTROLLERS_DIR.$controller.'.php';
	}

	protected function getModel($model)
	{
		include_once AM_MODULE_MODELS_DIR.$model.'.php';
	}

	protected function getView($template, $params = array(), $cache = true)
	{
		if (!$this->isViewCached($template))
		{
			$lang_data = array();
			$langs = Language::getLanguages();

			foreach ($langs as $lang)
				$lang_data[$lang['id_lang']] = Language::getLanguage($lang['id_lang']);

			$this->smarty->assign(array(
				'module_name' => $this->name,
				'module_display_name' => $this->displayName,
				'module_version' => $this->version,
				'module_url' => $this->_path
			));

			$this->smarty->assign(
				$params
			);
		}

		if ($cache)
			return $this->display(
				AM_MODULE_DIR.$this->name.'.php',
				AM_MODULE_REL_VIEWS_DIR.$template.'.tpl',
				$this->getCacheId($template)
			);
		else
			return $this->display(
				AM_MODULE_DIR.$this->name.'.php',
				AM_MODULE_REL_VIEWS_DIR.$template.'.tpl'
			);
	}

	public function isViewCached($template = null)
	{
		return $this->isCached(
			AM_MODULE_REL_VIEWS_DIR.$template.'.tpl',
			$this->getCacheId($template)
		);
	}

	public function clearCache($template = null)
	{
		$this->_clearCache(
			AM_MODULE_REL_VIEWS_DIR.$template.'.tpl'
		);
	}

	protected function getCacheId($template = null)
	{
		$cache_array = array();
		$cache_array[] = $this->name;

		if ($template != null)
			$cache_array[] = $template;

		if (Configuration::get('PS_SSL_ENABLED'))
			$cache_array[] = (int)Tools::usingSecureMode();

		if (Shop::isFeatureActive())
			$cache_array[] = (int)$this->context->shop->id;

		if (Group::isFeatureActive())
			$cache_array[] = (int)Group::getCurrent()->id;

		if (Language::isMultiLanguageActivated())
			$cache_array[] = (int)$this->context->language->id;

		if ($this->isMultiCurrencyActivated())
			$cache_array[] = (int)$this->context->currency->id;

		$cache_array[] = (int)$this->context->country->id;

		return implode('|', $cache_array);
	}

	public function countActiveCurrencies($id_shop = null)
	{
		if ($id_shop === null)
			$id_shop = (int)Context::getContext()->shop->id;

		if (!isset(self::$countActiveCurrencies[$id_shop]))
			self::$countActiveCurrencies[$id_shop] = Db::getInstance()->getValue('
				SELECT COUNT(DISTINCT c.id_currency) FROM `'._DB_PREFIX_.'currency` c
				LEFT JOIN '._DB_PREFIX_.'currency_shop cs ON (cs.id_currency = c.id_currency
				AND cs.id_shop = '.(int)$id_shop.')
				WHERE c.`active` = 1
			');
		return self::$countActiveCurrencies[$id_shop];
	}

	public function isMultiCurrencyActivated($id_shop = null)
	{
		return ($this->countActiveCurrencies($id_shop) > 1);
	}
}