<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

/**
 * Class AMRoute
 */
class AMRoute
{
	protected $prefix = 'AM';

	protected $module_name = 'admin';

	protected $controller_name = 'Menu';

	protected $method_name = 'index';

	protected $controller = false;

	protected $params = array();

	public function __construct()
	{
		$url = $this->parseUrl();

		if (isset($url[0]))
		{
			$this->module_name = $url[0];
			unset($url[0]);
		}

		if (isset($url[1]))
		{
			$this->controller_name = $url[1];
			unset($url[1]);
		}

		if (isset($url[2]))
		{
			$this->method_name = $url[2];
			unset($url[2]);
		}

		$this->module_name = $this->getCSFileName(AM_MODULE_DIR.'app/controllers', $this->module_name);

		if ($this->module_name == false)
			return;

		$this->controller_name = $this->getCSFileName(AM_MODULE_DIR.'app/controllers/'.$this->module_name,
			$this->controller_name, 'php');

		if ($this->controller_name == false)
			return;

		require_once AM_MODULE_DIR.'app/controllers/'.$this->module_name.'/'.$this->controller_name.'.php';

		$controller = $this->prefix.$this->controller_name;

		$this->controller = new $controller();

		$this->setParams($url);
	}

	protected function getCSFileName($folder, $file, $ext = '')
	{
		$return = false;

		if ($handle = opendir($folder))
			while (false !== ($entry = readdir($handle)))
				if (preg_match('/^'.(($ext == '') ? $file : $file.'\.'.$ext).'$/i', $entry))
					$return = $entry;

		return preg_replace('/\.'.$ext.'$/i', '', $return);
	}

	protected function parseUrl()
	{
		if (Tools::getValue('app', false))
			return explode('/', filter_var(rtrim(Tools::getValue('app'), ' / '), FILTER_SANITIZE_URL));

		return array();
	}

	protected function setParams($url = array())
	{
		$url = array_values($url);
		$this->params = array();

		foreach ($url as $key => $value)
			if ($key % 2 == 0)
				$this->params[$value] = $url[$key + 1];
	}

	public function getModuleName()
	{
		return $this->module_name;
	}

	public function getControllerName()
	{
		return $this->controller_name;
	}

	public function getMethodName()
	{
		return $this->method_name;
	}

	public function getController()
	{
		return $this->controller;
	}

	public function callMethod($method = false, $params = array(), $showerror = false)
	{
		if ($this->module_name == false)
			if ($showerror)
				return 'Module does not exist';
			else
				return false;

		if ($this->controller_name == false)
			if ($showerror)
				return 'Controller does not exist';
			else
				return false;

		if ($method == false || !method_exists($this->controller, $method))
			if ($showerror)
				return 'Method does not exist';
			else
				return false;

		return $this->controller->$method($params);
	}

	public function getContent()
	{
		return $this->callMethod($this->method_name, $this->params, true);
	}

	public function getParams()
	{
		return $this->params;
	}

	public static function getLink($path = '')
	{
		$params = array(
			'app' => $path,
			'controller' => 'AdminModules',
			'token' => Tools::getValue('token', false),
			'configure' => 'awemenu',
			'tab_module' => 'quick_bulk_update',
			'module_name' => 'awemenu'
		);

		return $_SERVER['PHP_SELF'].'?'.str_replace('%2F', '/', http_build_query($params));
	}
}