<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

/**
 * Class AMMenuModel
 */
class AMMenuModel extends AMModel
{
	public function getEditorMenu()
	{
		$sql = new DbQuery();
		$sql->select('*');
		$sql->from('awemenu');
		$sql->where('`edit` = 1');

		$row = Db::getInstance()->getRow($sql);
		$row['menu'] = Tools::jsonDecode($row['menu']);
		$row['theme'] = Tools::jsonDecode($row['theme']);

		return $row;
	}

	public function getLiveMenu()
	{
		$sql = new DbQuery();
		$sql->select('*');
		$sql->from('awemenu');
		$sql->where('`live` = 1');

		$row = Db::getInstance()->getRow($sql);
		$row['menu'] = Tools::jsonDecode($row['menu']);
		$row['theme'] = Tools::jsonDecode($row['theme']);

		return $row;
	}

	public function getRevisions()
	{
		$sql = new DbQuery();
		$sql->select('*, DATE_FORMAT(FROM_UNIXTIME(date), \'%a %D %b, %Y %h:%i %p\') as `date`');
		$sql->from('awemenu');
		$sql->where('`deleted` = 0');
		$sql->orderby('`id` DESC');

		return Db::getInstance()->executeS($sql);
	}

	public function getNumRevisions()
	{
		$sql = new DbQuery();
		$sql->select('COUNT(`id`) AS total');
		$sql->where('`deleted` = 0');
		$sql->from('awemenu');

		return Db::getInstance()->getValue($sql);
	}

	public function saveMenu($menu)
	{
		if ($menu->edit == '1')
			Db::getInstance()->update('awemenu', array(
				'edit' => 0
			));

		if ($menu->live == '1')
			Db::getInstance()->update('awemenu', array(
				'live' => 0
			));

		if (Db::getInstance()->insert('awemenu', array(
			'title' => $menu->title,
			'menu' => $menu->menu,
			'theme' => $menu->theme,
			'edit' => $menu->edit,
			'live' => $menu->live,
			'date' => time()
		))
		)
			return Db::getInstance()->Insert_ID();
		else
			return 0;
	}

	public function editRevision($id = null)
	{
		if ($id == null)
			return false;

		Db::getInstance()->update('awemenu', array(
			'edit' => 0
		));

		return Db::getInstance()->update('awemenu', array(
			'edit' => 1
		), '`id` = '.$id);
	}

	public function liveRevision($id = null)
	{
		if ($id == null)
			return false;

		Db::getInstance()->update('awemenu', array(
			'live' => 0
		));

		return Db::getInstance()->update('awemenu', array(
			'live' => 1
		), '`id` = '.$id);
	}

	public function deleteRevision($id = null)
	{
		if ($id == null)
			return false;

		$sql = new DbQuery();
		$sql->select('COUNT(`id`) AS total');
		$sql->from('awemenu');
		$sql->where('(`id` = '.$id.' AND `edit` = 1) OR (`id` = '.$id.' AND `live` = 1)');

		if (Db::getInstance()->getValue($sql) == 0)
			return Db::getInstance()->update('awemenu', array(
				'deleted' => 1
			), '`id` = '.$id);
		else
			return false;
	}
}