<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

/**
 * Class AMProductModel
 */
class AMProductModel extends AMModel
{
	public function getProducts($id_lang = null, $id_category = null, $search = '', $start = null, $limit = null,
								$orderfld = 'p.`id_product`', $orderdir = 'ASC')
	{
		$search_filtered = AMHelperFunctions::filterSearchQuery($search, array('id', 'text'));

		if ($id_lang == null)
			$id_lang = Context::getContext()->language->id;

		$sql = new DbQuery();
		$sql->select('p.`id_product`, l.`name`');
		$sql->from('product', 'p');
		$sql->leftJoin('product_lang', 'l', 'p.`id_product` = l.`id_product`');

		if ($id_category != null)
		{
			$sql->leftJoin('category_product', 'cp', 'p.`id_product` = cp.`id_product`');
			$sql->where('cp.`id_category` = '.(int)$id_category);
		}

		if ($search_filtered['id'] != '')
			$sql->where('p.`id_product` IN ('.(int)$search_filtered['id'].')');

		if ($search_filtered['text'] != '')
			$sql->where('l.`name` LIKE \'%'.$search_filtered['text'].'%\'');

		if ($search_filtered['id'] == '' && $search_filtered['text'] == '' && $search_filtered['query'] != '')
			$sql->where('l.`name` LIKE \'%'.$search_filtered['query'].'%\'');

		$sql->where('l.`id_lang` = '.(int)$id_lang);
		$sql->where('p.`active` = 1');

		if ($limit !== null && $start !== null)
			$sql->limit($limit, $start);

		if ($orderfld == 'entity_item_id')
			$orderfld = 'p.`id_product`';

		if ($orderfld == 'text')
			$orderfld = 'l.`name`';

		if ($orderfld != '' && $orderdir != '')
			$sql->orderby($orderfld.' '.$orderdir);

		return Db::getInstance()->executeS($sql);
	}

	public function getNumProducts($id_category = null, $search = '')
	{
		$search_filtered = AMHelperFunctions::filterSearchQuery($search, array('id', 'text'));

		$sql = new DbQuery();
		$sql->select('COUNT(DISTINCT p.`id_product`) AS total');
		$sql->from('product', 'p');
		$sql->leftJoin('product_lang', 'l', 'p.`id_product` = l.`id_product`');

		if ($id_category != null)
		{
			$sql->leftJoin('category_product', 'cp', 'p.`id_product` = cp.`id_product`');
			$sql->where('cp.`id_category` = '.(int)$id_category);
		}

		if ($search_filtered['id'] != '')
			$sql->where('p.`id_product` IN ('.(int)$search_filtered['id'].')');

		if ($search_filtered['text'] != '')
			$sql->where('l.`name` LIKE \'%'.$search_filtered['text'].'%\'');

		if ($search_filtered['id'] == '' && $search_filtered['text'] == '' && $search_filtered['query'] != '')
			$sql->where('l.`name` LIKE \'%'.$search_filtered['query'].'%\'');

		$sql->where('p.`active` = 1');

		return Db::getInstance()->getValue($sql);
	}
}