<?php
/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

if (!defined('_PS_VERSION_'))
	exit;

require_once 'app/autoload.php';

class AweMenu extends Module
{
	protected $route;

	public function __construct()
	{
		$this->name = 'awemenu';
		$this->author = 'Kahanit';
		$this->version = '1.0.3';
		$this->tab = 'front_office_features';
		$this->need_instance = 0;
		$this->module_key = '7eb5ddcbbf81883093b648ca4f4a07f3';

		if (version_compare(_PS_VERSION_, '1.6.0.1') >= 0)
			$this->bootstrap = true;
		else
			$this->bootstrap = false;

		parent::__construct();

		$this->displayName = $this->l('Awe Menu - Responsive Top Horizontal Mega Menu');
		$this->description = $this->l('Quick, easy to setup and WYSIWYG menu management module');
		//$this->ps_versions_compliancy = array('min' => '1.5.1.0', 'max' => _PS_VERSION_);
		$this->confirmUninstall = $this->l('Are you sure?');

		if (!isset($this->context->employee))
			$_GET['app'] = 'front/menu/getlivemenu';

		$this->route = new AMRoute();
	}

	public function install()
	{
		include(dirname(__FILE__).'/sql/install.php');

		if (!parent::install()
			|| !$this->registerHook('displayBackOfficeHeader')

			|| !$this->registerHook('header')
			|| !$this->registerHook('displayTop')

			|| !$this->registerHook('actionObjectProductUpdateAfter')
			|| !$this->registerHook('actionObjectCategoryUpdateAfter')
			|| !$this->registerHook('actionObjectCmsUpdateAfter')
			|| !$this->registerHook('actionObjectManufacturerUpdateAfter')
			|| !$this->registerHook('actionObjectSupplierUpdateAfter')

			|| !$this->registerHook('actionObjectProductDeleteAfter')
			|| !$this->registerHook('actionObjectCategoryDeleteAfter')
			|| !$this->registerHook('actionObjectCmsDeleteAfter')
			|| !$this->registerHook('actionObjectManufacturerDeleteAfter')
			|| !$this->registerHook('actionObjectSupplierDeleteAfter')
		)
			return false;

		return true;
	}

	public function uninstall()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');

		include(dirname(__FILE__).'/sql/uninstall.php');

		if (!parent::uninstall()
			|| !$this->unregisterHook('displayBackOfficeHeader')

			|| !$this->unregisterHook('header')
			|| !$this->unregisterHook('displayTop')

			|| !$this->unregisterHook('actionObjectProductUpdateAfter')
			|| !$this->unregisterHook('actionObjectCategoryUpdateAfter')
			|| !$this->unregisterHook('actionObjectCmsUpdateAfter')
			|| !$this->unregisterHook('actionObjectManufacturerUpdateAfter')
			|| !$this->unregisterHook('actionObjectSupplierUpdateAfter')

			|| !$this->unregisterHook('actionObjectProductDeleteAfter')
			|| !$this->unregisterHook('actionObjectCategoryDeleteAfter')
			|| !$this->unregisterHook('actionObjectCmsDeleteAfter')
			|| !$this->unregisterHook('actionObjectManufacturerDeleteAfter')
			|| !$this->unregisterHook('actionObjectSupplierDeleteAfter')
		)
			return false;

		return true;
	}

	public function getContent()
	{
		return $this->route->getContent();
	}

	public function hookDisplayBackOfficeHeader()
	{
		if (strcasecmp(Tools::getValue('controller'), 'AdminModules') != 0
			|| strcasecmp(Tools::getValue('configure'), $this->name) != 0
		)
			return;

		return $this->route->callMethod('hookDisplayBackOfficeHeader', $this->bootstrap);
	}

	public function hookHeader()
	{
		return $this->route->callMethod('hookHeader');
	}

	public function hookDisplayTop()
	{
		return $this->route->getContent();
	}

	public function hookActionObjectProductUpdateAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectCategoryUpdateAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectCmsUpdateAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectManufacturerUpdateAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectSupplierUpdateAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectProductDeleteAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectCategoryDeleteAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectCmsDeleteAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectManufacturerDeleteAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}

	public function hookActionObjectSupplierDeleteAfter()
	{
		$this->route->callMethod('clearCache', 'front/menu/menu');
	}
}