/**
 * Easily manage navigation with Kahanit Awe Menu
 *
 * Kahanit Awe Menu by Kahanit(http://www.kahanit.com) is licensed under a
 * Creative Creative Commons Attribution-NoDerivatives 4.0 International License.
 * Based on a work at http://www.kahanit.com.
 * Permissions beyond the scope of this license may be available at http://www.kahanit.com.
 * To view a copy of this license, visit http://creativecommons.org/licenses/by-nd/4.0/.
 *
 * @author    Amit Sidhpura <amit@kahanit.com>
 * @copyright 2015 Kahanit
 * @license   http://creativecommons.org/licenses/by-nd/4.0/
 */

var awemenu_js_dir = '';
var CKEDITOR_BASEPATH = '';

var awemenu_version_compare = function (v1, v2, operator)
{
	this.php_js = this.php_js || {};
	this.php_js.ENV = this.php_js.ENV || {};

	var i = 0,
		x = 0,
		compare = 0,
		vm = {
			'dev': -6,
			'alpha': -5,
			'a': -5,
			'beta': -4,
			'b': -4,
			'RC': -3,
			'rc': -3,
			'#': -2,
			'p': 1,
			'pl': 1
		},
		prepVersion = function (v)
		{
			v = ('' + v)
				.replace(/[_\-+]/g, '.');
			v = v.replace(/([^.\d]+)/g, '.$1.')
				.replace(/\.{2,}/g, '.');
			return (!v.length ? [-8] : v.split('.'));
		};

	var numVersion = function (v)
	{
		return !v ? 0 : (isNaN(v) ? vm[v] || -7 : parseInt(v, 10));
	};

	v1 = prepVersion(v1);
	v2 = prepVersion(v2);
	x = Math.max(v1.length, v2.length);

	for (i = 0; i < x; i++)
	{
		if (v1[i] == v2[i])
			continue;

		v1[i] = numVersion(v1[i]);
		v2[i] = numVersion(v2[i]);

		if (v1[i] < v2[i])
		{
			compare = -1;
			break;
		}
		else if (v1[i] > v2[i])
		{
			compare = 1;
			break;
		}
	}

	if (!operator)
		return compare;

	switch (operator)
	{
		case '>':
		case 'gt':
			return (compare > 0);
		case '>=':
		case 'ge':
			return (compare >= 0);
		case '<=':
		case 'le':
			return (compare <= 0);
		case '==':
		case '=':
		case 'eq':
			return (compare === 0);
		case '<>':
		case '!=':
		case 'ne':
			return (compare !== 0);
		case '':
		case '<':
		case 'lt':
			return (compare < 0);
		default:
			return null;
	}
};

window.onload = function ()
{
	var scripts = '',
		nojQueryFlag = false;

	awemenu_js_dir = awemenu_module_url + 'js/';
	CKEDITOR_BASEPATH = awemenu_js_dir + 'ckeditor/';

	if (awemenu_version_compare(jQuery.fn.jquery, '1.9.1', '<'))
	{
		scripts += '<script type="text/javascript">var awemenu_jquery_old = jQuery.noConflict(true);</script>';
		scripts += '<script type="text/javascript" src="' + awemenu_js_dir + 'jquery.min.js" />';

		nojQueryFlag = true;
	}

	if (typeof(jQuery.fn.modal) === 'undefined')
		scripts += '<script type="text/javascript" src="' + awemenu_js_dir + 'bootstrap.min.js" />';

	scripts += '\
		<script type="text/javascript" src="' + awemenu_js_dir + 'jquery-ui.min.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'jquery.dataTables.min.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'jquery.dataTables.bootstrap.min.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'jquery.fancytree-all.min.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'bootstrap-colorpicker.min.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'fontawesome-iconpicker.min.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'ckeditor/ckeditor.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'ckeditor/adapters/jquery.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'handlebars.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'ace.js" />\
		<script type="text/javascript" src="' + awemenu_js_dir + 'jquery.awemenu.js" />\
	';

	if (nojQueryFlag)
		scripts += '<script type="text/javascript">\
			var awemenu_jquery = jQuery.noConflict(true);\
			$ = awemenu_jquery_old;\
			jQuery = awemenu_jquery_old;\
		</script>';

	if (typeof awemenu_jquery == 'undefined')
		awemenu_jquery = jQuery;

	awemenu_jquery('head').append(scripts);
	awemenu_jquery('#awemenu').awemenu({
		'url': awemenu_url,
		'langs': awemenu_langs,
		'activeLang': awemenu_activelang,
		'entities': awemenu_entities
	});
};